@@ -7,6 +7,7 @@ import sys
 import urllib
 import xml.etree.ElementTree as etree
 import urllib.request
+import zlib
 
 cmdversions = {
 	"vkCmdSetDiscardRectangleEnableEXT": 2,
@@ -52,7 +53,7 @@ def is_descendant_type(types, name, base):
 	if name == base:
 		return True
 	type = types.get(name)
-	if not type:
+	if type is None:
 		return False
 	parents = type.get('parent')
 	if not parents:
@@ -157,12 +158,17 @@ if __name__ == "__main__":
 	for key in block_keys:
 		blocks[key] = ''
 
+	devp = {}
+
 	for (group, cmdnames) in command_groups.items():
 		ifdef = '#if ' + group + '\n'
 
 		for key in block_keys:
 			blocks[key] += ifdef
 
+		devt = 0
+		devo = len(blocks['DEVICE_TABLE'])
+
 		for name in sorted(cmdnames):
 			cmd = commands[name]
 			type = cmd.findtext('param[1]/type')
@@ -176,6 +182,7 @@ if __name__ == "__main__":
 				blocks['LOAD_DEVICE'] += '\t' + name + ' = (PFN_' + name + ')load(context, "' + name + '");\n'
 				blocks['DEVICE_TABLE'] += '\tPFN_' + name + ' ' + name + ';\n'
 				blocks['LOAD_DEVICE_TABLE'] += '\ttable->' + name + ' = (PFN_' + name + ')load(context, "' + name + '");\n'
+				devt += 1
 			elif is_descendant_type(types, type, 'VkInstance'):
 				blocks['LOAD_INSTANCE'] += '\t' + name + ' = (PFN_' + name + ')load(context, "' + name + '");\n'
 			elif type != '':
@@ -187,6 +194,14 @@ if __name__ == "__main__":
 		for key in block_keys:
 			if blocks[key].endswith(ifdef):
 				blocks[key] = blocks[key][:-len(ifdef)]
+			elif key == 'DEVICE_TABLE':
+				devh = zlib.crc32(blocks[key][devo:].encode())
+				assert(devh not in devp)
+				devp[devh] = True
+
+				blocks[key] += '#else\n'
+				blocks[key] += f'\tPFN_vkVoidFunction padding_{devh:x}[{devt}];\n'
+				blocks[key] += '#endif /* ' + group + ' */\n'
 			else:
 				blocks[key] += '#endif /* ' + group + ' */\n'
 
